.. qcware documentation master file, created by
   sphinx-quickstart on Tue Aug 20 12:53:08 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Table of contents
-----------------

.. toctree::
   :maxdepth: 2
   :caption: Optimization

   optimization/solve_binary

.. toctree::
   :maxdepth: 2
   :caption: Circuits

   circuits/circuits
   
.. toctree::
   :maxdepth: 2
   :caption: Quantum classification

   qml/classification

.. toctree::
   :maxdepth: 2
   :caption: Copyright

   copyright
